@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Test Products.CMFDefault.browser.folder with CMFBTreeFolder
-
-$Id: test_btreefolder.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+""" Test Products.CMFDefault.browser.folder with CMFBTreeFolder """
 
 import unittest
 from Testing import ZopeTestCase
