@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" CMFDefault.interfaces package.
-
-$Id: __init__.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+""" CMFDefault.interfaces package. """
 
 from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 from _content import *
@@ -24,16 +21,3 @@ class ICMFDefaultSkin(IDefaultBrowserLayer):
 
     """CMF default skin.
     """
-
-
-# BBB: will be removed in CMF 2.2
-#      create zope2 interfaces
-from Interface.bridge import createZope3Bridge
-import Document
-import portal_membership
-
-createZope3Bridge(IDocument, Document, 'IDocument')
-createZope3Bridge(IMutableDocument, Document, 'IMutableDocument')
-createZope3Bridge(IMembershipTool, portal_membership, 'portal_membership')
-
-del createZope3Bridge
