@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for Document module.
-
-$Id: test_Document.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+""" Unit tests for Document module. """
 
 import unittest
 import Testing
