@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Upgrade steps to CMFDefault 2.2.
-
-$Id: to22.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+"""Upgrade steps to CMFDefault 2.2. """
 import logging
 from urllib import quote
 
